Libp2p.SecureChannel (libp2p_elixir v0.9.0)
Secure channel abstraction (e.g. Noise XX).
A secure channel wraps an underlying transport stream and provides encrypted read/write plus authenticated remote identity.
Secure channel abstraction (e.g. Noise XX).
A secure channel wraps an underlying transport stream and provides encrypted read/write plus authenticated remote identity.