Libp2p.StreamNegotiator (libp2p_elixir v0.9.0)
Multistream-select negotiation on top of an established yamux stream.
Uses Libp2p.Connection.stream_send/3 and stream_recv/3 as the transport.
Summary
Types
@type proto_id() :: binary()
Multistream-select negotiation on top of an established yamux stream.
Uses Libp2p.Connection.stream_send/3 and stream_recv/3 as the transport.
@type proto_id() :: binary()